Module client

Module client 

A high-level client for Zephyr’s MCUmgr SMP functionality

Modules

image_run_state
High-level image run state derived from the image state flags

Structs

BleDeviceInfoble
Information about a BLE device
BleDevicesble
A list of available BLE devices
FirmwareUpdateParams
Configurable parameters for MCUmgrClient::firmware_update.
MCUmgrClient
A high-level client for Zephyr’s MCUmgr SMP protocol.
UsbSerialPortInfo
Information about a serial port
UsbSerialPorts
A list of available serial ports

Enums

BleErrorble
Possible error values of MCUmgrClient::new_from_ble.
FirmwareUpdateError
Possible error values of MCUmgrClient::firmware_update.
FirmwareUpdateStep
The step of the firmware update that is currently being performed
MCUmgrClientError
Possible error values of MCUmgrClient.
UdpError
Possible error values of MCUmgrClient::new_from_udp.
UsbSerialError
Possible error values of MCUmgrClient::new_from_usb_serial.

Type Aliases

FirmwareUpdateProgressCallback
The progress callback type of MCUmgrClient::firmware_update.