pub enum FirmwareUpdateStep {
DetectingBootloader,
BootloaderFound(BootloaderType),
ParsingFirmwareImage,
QueryingDeviceState,
UpdateInfo {
current_version: Option<(String, Option<Vec<u8>>)>,
new_version: (String, Vec<u8>),
},
UploadingFirmware,
ActivatingFirmware,
TriggeringReboot,
}Expand description
The step of the firmware update that is currently being performed
Variants
DetectingBootloader
Querying which bootloader the device is running
BootloaderFound(BootloaderType)
The bootloader was found
ParsingFirmwareImage
Extracting meta information from the new firmware image
QueryingDeviceState
Querying the current firmware state of the device
UpdateInfo
A summary of what update exactly we will perform now
Fields
UploadingFirmware
Uploading the new firmware to the device
ActivatingFirmware
Marking the new firmware to be swapped to active during next boot
TriggeringReboot
Triggering a system reboot so that the bootloader switches to the new image