pub enum MCUmgrClientError {
ExecuteError(ExecuteError),
UnexpectedOffset,
WriterError(Error),
ReaderError(Error),
SizeMismatch,
MissingSize,
ProgressCallbackError,
FrameSizeTooSmall(Error),
ChecksumMismatchOnDevice,
ChecksumMismatch,
SetTimeoutFailed(Box<dyn Error + Send + Sync>),
}Expand description
Possible error values of MCUmgrClient.
Variants
ExecuteError(ExecuteError)
The command failed in the SMP protocol layer.
UnexpectedOffset
A device response contained an unexpected offset value.
WriterError(Error)
The writer returned an error.
ReaderError(Error)
The reader returned an error.
SizeMismatch
The received data does not match the reported file size.
MissingSize
The received data unexpectedly did not report the file size.
ProgressCallbackError
The progress callback returned an error.
FrameSizeTooSmall(Error)
The current SMP frame size is too small for this command.
ChecksumMismatchOnDevice
The device reported a checksum mismatch
ChecksumMismatch
The firmware image does not match the given checksum
SetTimeoutFailed(Box<dyn Error + Send + Sync>)
Setting the device timeout failed
Implementations
Sourceimpl MCUmgrClientError
impl MCUmgrClientError
Sourcepub fn command_not_supported(&self) -> bool
pub fn command_not_supported(&self) -> bool
Checks if the device reported the command as unsupported