pub enum ImageRunState<'a> {
Stable(&'a ImageState),
Pending {
current: Option<&'a ImageState>,
next: &'a ImageState,
},
Testing {
current: &'a ImageState,
fallback: &'a ImageState,
},
Unknown(Option<&'a ImageState>),
Inconsistent,
}Expand description
The current run state of the given image.
Variants
Stable(&'a ImageState)
The given slot is likely the current and future image on the system.
Pending
The image will change at next boot.
Fields

current: Option<&'a ImageState>Currently running/active image, if known.

next: &'a ImageStateThe slot that will run after next boot.
Examine next.permanent to see whether
the image will boot in testing or permanent
mode.
Testing
A new image is currently being tested.
Unless it gets confirmed, it will be rolled back at next boot.
Fields

current: &'a ImageStateThe currently tested image.

fallback: &'a ImageStateThe image that will get rolled back to.
Unknown(Option<&'a ImageState>)
The current state is not easily determinable.
Will contain an educated guess if possible, but by no means this guess should be relied upon.
Inconsistent
The image state is inconsistent.
Example: The image has multiple slots that are marked ‘active’.