pub struct SetImageState<'a> {
pub hash: Option<&'a [u8]>,
pub confirm: bool,
}Expand description
Set Image State command
Fields
hash: Option<&'a [u8]>Hash of the image header and body
If confirm is true this can be omitted, which will select the currently running image.
Note that this will not be the same as the SHA256 of the whole file, it is the field in the MCUboot TLV section that contains a hash of the data which is used for signature verification purposes.
confirm: boolIf true, mark the given image as ‘confirmed’.
If false, perform a test boot with the given image and revert upon hard reset.