pub struct SlotInfoImageSlot {
pub slot: u32,
pub size: u64,
pub upload_image_id: Option<u32>,
}Expand description
Information about a slot that can hold a firmware image
Fields
slot: u32The slot inside the image being enumerated
size: u64The size of the slot
upload_image_id: Option<u32>Specifies the image ID that can be used by external tools to upload an image to that slot