pub struct ReadSettingResponse {
pub val: Vec<u8>,
pub max_size: Option<u32>,
}Expand description
Response for ReadSetting command
Fields
val: Vec<u8>The returned data.
Note that the underlying data type cannot be specified through this and must be known by the client.
max_size: Option<u32>Will be set if the maximum supported data size is smaller than the maximum requested data size, and contains the maximum data size which the device supports