pub struct ImageInfo {
pub version: ImageVersion,
pub hash: ImageHashId,
}Expand description
Information about an MCUboot firmware image
Fields
version: ImageVersionFirmware version
hash: ImageHashIdThe identifying hash for the firmware
Note that this will not be the same as the SHA256 of the whole file, it is the field in the MCUboot TLV section that contains a hash of the data which is used for signature verification purposes.