#[repr(i32)]pub enum FsMgmtErrCode {
Show 17 variants
FS_MGMT_ERR_OK = 0,
FS_MGMT_ERR_UNKNOWN = 1,
FS_MGMT_ERR_FILE_INVALID_NAME = 2,
FS_MGMT_ERR_FILE_NOT_FOUND = 3,
FS_MGMT_ERR_FILE_IS_DIRECTORY = 4,
FS_MGMT_ERR_FILE_OPEN_FAILED = 5,
FS_MGMT_ERR_FILE_SEEK_FAILED = 6,
FS_MGMT_ERR_FILE_READ_FAILED = 7,
FS_MGMT_ERR_FILE_TRUNCATE_FAILED = 8,
FS_MGMT_ERR_FILE_DELETE_FAILED = 9,
FS_MGMT_ERR_FILE_WRITE_FAILED = 10,
FS_MGMT_ERR_FILE_OFFSET_NOT_VALID = 11,
FS_MGMT_ERR_FILE_OFFSET_LARGER_THAN_FILE = 12,
FS_MGMT_ERR_CHECKSUM_HASH_NOT_FOUND = 13,
FS_MGMT_ERR_MOUNT_POINT_NOT_FOUND = 14,
FS_MGMT_ERR_READ_ONLY_FILESYSTEM = 15,
FS_MGMT_ERR_FILE_EMPTY = 16,
}Expand description
See enum fs_mgmt_err_code_t.
Variants
FS_MGMT_ERR_OK = 0
No error (success).
FS_MGMT_ERR_UNKNOWN = 1
Unknown error occurred.
FS_MGMT_ERR_FILE_INVALID_NAME = 2
The specified file name is not valid.
FS_MGMT_ERR_FILE_NOT_FOUND = 3
The specified file does not exist.
FS_MGMT_ERR_FILE_IS_DIRECTORY = 4
The specified file is a directory, not a file.
FS_MGMT_ERR_FILE_OPEN_FAILED = 5
Error occurred whilst attempting to open a file.
FS_MGMT_ERR_FILE_SEEK_FAILED = 6
Error occurred whilst attempting to seek to an offset in a file.
FS_MGMT_ERR_FILE_READ_FAILED = 7
Error occurred whilst attempting to read data from a file.
FS_MGMT_ERR_FILE_TRUNCATE_FAILED = 8
Error occurred whilst trying to truncate file.
FS_MGMT_ERR_FILE_DELETE_FAILED = 9
Error occurred whilst trying to delete file.
FS_MGMT_ERR_FILE_WRITE_FAILED = 10
Error occurred whilst attempting to write data to a file.
FS_MGMT_ERR_FILE_OFFSET_NOT_VALID = 11
The specified data offset is not valid, this could indicate that the file on the device has changed since the previous command. The length of the current file on the device is returned as “len”, the user application needs to decide how to handle this (e.g. the hash of the file could be requested and compared with the hash of the length of the file being uploaded to see if they match or not).
FS_MGMT_ERR_FILE_OFFSET_LARGER_THAN_FILE = 12
The requested offset is larger than the size of the file on the device.
FS_MGMT_ERR_CHECKSUM_HASH_NOT_FOUND = 13
The requested checksum or hash type was not found or is not supported by this build.
FS_MGMT_ERR_MOUNT_POINT_NOT_FOUND = 14
The specified mount point was not found or is not mounted.
FS_MGMT_ERR_READ_ONLY_FILESYSTEM = 15
The specified mount point is that of a read-only filesystem.
FS_MGMT_ERR_FILE_EMPTY = 16
The operation cannot be performed because the file is empty with no contents.
Implementations
Sourceimpl FsMgmtErrCode
impl FsMgmtErrCode