#[repr(i32)]pub enum SettingsMgmtRetCode {
SETTINGS_MGMT_ERR_OK = 0,
SETTINGS_MGMT_ERR_UNKNOWN = 1,
SETTINGS_MGMT_ERR_KEY_TOO_LONG = 2,
SETTINGS_MGMT_ERR_KEY_NOT_FOUND = 3,
SETTINGS_MGMT_ERR_READ_NOT_SUPPORTED = 4,
SETTINGS_MGMT_ERR_ROOT_KEY_NOT_FOUND = 5,
SETTINGS_MGMT_ERR_WRITE_NOT_SUPPORTED = 6,
SETTINGS_MGMT_ERR_DELETE_NOT_SUPPORTED = 7,
SETTINGS_MGMT_ERR_SAVE_NOT_SUPPORTED = 8,
}Expand description
See enum settings_mgmt_ret_code_t.
Variants
SETTINGS_MGMT_ERR_OK = 0
No error, this is implied if there is no ret value in the response.
SETTINGS_MGMT_ERR_UNKNOWN = 1
Unknown error occurred.
SETTINGS_MGMT_ERR_KEY_TOO_LONG = 2
The provided key name is too long to be used.
SETTINGS_MGMT_ERR_KEY_NOT_FOUND = 3
The provided key name does not exist.
SETTINGS_MGMT_ERR_READ_NOT_SUPPORTED = 4
The provided key name does not support being read.
SETTINGS_MGMT_ERR_ROOT_KEY_NOT_FOUND = 5
The provided root key name does not exist.
SETTINGS_MGMT_ERR_WRITE_NOT_SUPPORTED = 6
The provided key name does not support being written.
SETTINGS_MGMT_ERR_DELETE_NOT_SUPPORTED = 7
The provided key name does not support being deleted.
SETTINGS_MGMT_ERR_SAVE_NOT_SUPPORTED = 8
The provided key name does not support being saved.
Implementations